<?php
// $Id$

/**
 * @file
 * Class for v1.0 of the Convio Open Server API.
 */

class ConvioServerApi {

  /**
   * @var string
   *  The version of the API that is to be used.
   */
  private $version = '1.0';

  /**
   * @var string
   *  The host name of the secure Convio cluster that the site resides on.
   */
  protected $endPoint;

  /**
   * @var string
   *  This is the API Key for the Convio Open API.
   */
  protected $apiKey;

  /**
   * @var string
   *  Format of the response (php, xml, or json)
   */
  protected $responseFormat;

  /**
   * @var string
   *  The API username. This is different from the Web interface username.
   */
  protected $username;

  /**
   * @var string
   *  The API password. This is different from the Web interface password.
   */
  protected $password;


  /**
   * Class contructor allowing setting variables during object init.
   */
  public function __construct($endPoint, $apiKey, $username, $password, $responseFormat = 'json') {
    $this->endPoint       = $endPoint;
    $this->apiKey         = $apiKey;
    $this->username       = $username;
    $this->password       = $password;
    $this->responseFormat = $responseFormat;
  }

  /**
   * Makes HTTP request to Convio web service.
   *
   * @return
   *  A PHP object with the request and response data.
   */
  protected function httpRequest($method, $params) {
    // Force content type header because default is not always correct.
    $headers = array(
      'Content-type' => 'application/x-www-form-urlencoded',
    );
    $defaultParams = array(
      'v' => $this->version,
      'response_format' => $this->responseFormat,
      'login_name' => $this->username,
      'login_password' => $this->password,
      'api_key' => $this->apiKey,
      'method' => $method,
    );
    $data = drupal_query_string_encode(array_merge($defaultParams, $params));
    $response = drupal_http_request($this->endPoint, $headers, 'POST', $data);

    return $this->prepareResponse($response);
  }

  /**
   *
   *
   * @param $response
   *  Drupal HTTP respose object.
   *
   * @return mixed
   *  A PHP object with request and response data correctly formated.
   */
  protected function prepareResponse($response) {
    switch ($this->responseFormat) {
      case 'xml':
        $response->object = simplexml_load_string($response->data);
        break;

      case 'json':
        $response->object = json_decode($response->data);
        break;
    }
    return $response;
  }

  /**
   *
   *
   * @return
   *
   */
  public function request($method, array $params = array()) {
    return $this->httpRequest($method, $params);
  }

}
